@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,9 +12,8 @@
 #
 ##############################################################################
 """Test the gts ZCML namespace directives.
-
-$Id: test_zcml.py 102560 2009-08-07 12:22:51Z hannosch $
 """
+import doctest
 import os
 import shutil
 import stat
@@ -154,6 +153,27 @@ class DirectivesTest(PlacelessSetup, unittest.TestCase):
         # Reset the mtime of the mo file
         os.utime(path, (path_atime, path_mtime))
 
+    def testRegisterTranslationsForDomain(self):
+        from zope.configuration import xmlconfig
+        self.assert_(queryUtility(ITranslationDomain, 'zope-i18n') is None)
+        self.assert_(queryUtility(ITranslationDomain, 'zope-i18n2') is None)
+        xmlconfig.string(
+            template % '''
+            <configure package="zope.i18n.tests">
+            <i18n:registerTranslations directory="locale3" domain="zope-i18n" />
+            </configure>
+            ''', self.context)
+        path = os.path.join(os.path.dirname(zope.i18n.tests.__file__),
+                            'locale3', 'en', 'LC_MESSAGES', 'zope-i18n.mo')
+        util = getUtility(ITranslationDomain, 'zope-i18n')
+        self.assertEquals(util._catalogs,
+                          {'test': ['test'], 'en': [unicode(path)]})
+
+        self.assert_(queryUtility(ITranslationDomain, 'zope-i18n2') is None)
+
 
 def test_suite():
-    return unittest.makeSuite(DirectivesTest)
+    return unittest.TestSuite((
+            unittest.makeSuite(DirectivesTest),
+            doctest.DocFileSuite('configure.txt'),
+            ))
